Documentation
¶
Rendered for js/wasm
Index ¶
- func Await(p js.Value) (js.Value, error)
- type OPFS
- func (fs *OPFS) Chroot(path string) (billy.Filesystem, error)
- func (fs *OPFS) Create(name string) (billy.File, error)
- func (fs *OPFS) Join(elem ...string) string
- func (fs *OPFS) Lstat(filename string) (fs.FileInfo, error)
- func (fs *OPFS) MkdirAll(path string, perm fs.FileMode) error
- func (fs *OPFS) Open(name string) (billy.File, error)
- func (fs *OPFS) OpenFile(fullPath string, flag int, perm os.FileMode) (billy.File, error)
- func (fs *OPFS) ReadDir(path string) (infos []os.FileInfo, err error)
- func (fs *OPFS) Readlink(link string) (string, error)
- func (fs *OPFS) Remove(path string) error
- func (fs *OPFS) Rename(oldpath, newpath string) error
- func (fs *OPFS) Root() string
- func (fs *OPFS) Stat(path string) (os.FileInfo, error)
- func (fs *OPFS) Symlink(target, link string) error
- func (fs *OPFS) TempFile(dir string, prefix string) (billy.File, error)
- type OPFSFile
- func (f *OPFSFile) Close() error
- func (f *OPFSFile) Lock() error
- func (f *OPFSFile) Name() (name string)
- func (f *OPFSFile) Read(p []byte) (int, error)
- func (f *OPFSFile) ReadAt(p []byte, off int64) (n int, err error)
- func (f *OPFSFile) Seek(offset int64, whence int) (newOffset int64, err error)
- func (f *OPFSFile) Truncate(size int64) error
- func (f *OPFSFile) Unlock() error
- func (f *OPFSFile) Write(p []byte) (int, error)
- func (f *OPFSFile) WriteAt(p []byte, off int64) (n int, err error)
- type OPFSFileInfo
- func (fi *OPFSFileInfo) Info() (fs.FileInfo, error)
- func (fi *OPFSFileInfo) IsDir() bool
- func (fi *OPFSFileInfo) ModTime() time.Time
- func (fi *OPFSFileInfo) Mode() os.FileMode
- func (fi *OPFSFileInfo) Name() string
- func (fi *OPFSFileInfo) Size() int64
- func (fi *OPFSFileInfo) Sys() any
- func (fi *OPFSFileInfo) Type() fs.FileMode
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type OPFS ¶
Origin private file system
https://developer.mozilla.org/en-US/docs/Web/API/File_System_API/Origin_private_file_system
type OPFSFile ¶
type OPFSFile struct {
// contains filtered or unexported fields
}
This struct represents a file in our OPFS FileSystem, but there can by multiple instances of the single file, with different offsets, pointing at the same inode (aka. the REAL file)
type OPFSFileInfo ¶
type OPFSFileInfo struct {
// contains filtered or unexported fields
}
func (*OPFSFileInfo) IsDir ¶
func (fi *OPFSFileInfo) IsDir() bool
func (*OPFSFileInfo) ModTime ¶
func (fi *OPFSFileInfo) ModTime() time.Time
func (*OPFSFileInfo) Mode ¶
func (fi *OPFSFileInfo) Mode() os.FileMode
Mode returns the file permissions. Git checks this to see if a file is executable or a directory.
func (*OPFSFileInfo) Name ¶
func (fi *OPFSFileInfo) Name() string
func (*OPFSFileInfo) Size ¶
func (fi *OPFSFileInfo) Size() int64
func (*OPFSFileInfo) Sys ¶
func (fi *OPFSFileInfo) Sys() any
func (*OPFSFileInfo) Type ¶
func (fi *OPFSFileInfo) Type() fs.FileMode
Click to show internal directories.
Click to hide internal directories.